@@ -11,7 +11,8 @@ class Msg(object):
 class Document(object):
     def __init__(self, files, id=None, category=None, doctype=None, federal_level=None, authority=None,
                  authority_url=None, title=None, number=None, abbreviation=None, instance=None, type=None,
-                 subtype=None, decree_date=None, enactment_date=None, abrogation_date=None, cycle=None):
+                 subtype=None, decree_date=None, enactment_date=None, abrogation_date=None, cycle=None,
+                 municipality=None, index=None, status=None, status_start_date=None, status_end_date=None):
         """Creates a new document instance.
 
         Args:
@@ -32,6 +33,11 @@ class Document(object):
             enactment_date (datetime.date): The date of enactment.
             abrogation_date (datetime.date): The date of abrogation.
             cycle (str): The document cycle.
+            municipality (str): The municipality concerned by this document.
+            index (int): The document's index for sorting.
+            status (str): The status of the prebublication.
+            status_start_date (datetime.date): Start date of the status.
+            status_end_date (datetime.date): End date of the status.
 
         Raises:
             TypeError: Raised on missing argument or invalid argument type.
@@ -62,7 +68,21 @@ class Document(object):
 
         if abrogation_date and not isinstance(abrogation_date, datetime.date):
             raise TypeError(Msg.invalid_argument.format(
-                arg='decree_date',
+                arg='abrogation_date',
+                expected=datetime.date,
+                got=decree_date.__class__
+            ))
+
+        if status_start_date and not isinstance(status_start_date, datetime.date):
+            raise TypeError(Msg.invalid_argument.format(
+                arg='status_start_date',
+                expected=datetime.date,
+                got=decree_date.__class__
+            ))
+
+        if status_end_date and not isinstance(status_end_date, datetime.date):
+            raise TypeError(Msg.invalid_argument.format(
+                arg='status_end_date',
                 expected=datetime.date,
                 got=decree_date.__class__
             ))
@@ -84,6 +104,11 @@ class Document(object):
         self._enactment_date = enactment_date
         self._abrogation_date = abrogation_date
         self._cycle = cycle
+        self._municipality = municipality
+        self._index = None if index is None else int(index)
+        self._status = status
+        self._status_start_date = status_start_date
+        self._status_end_date = status_end_date
 
     @property
     def files(self):
@@ -170,6 +195,31 @@ class Document(object):
         """str: The document cycle (v1.0.0 only)."""
         return self._cycle
 
+    @property
+    def municipality(self):
+        """str: The municipality concerned by this document (since v1.2.1)."""
+        return self._municipality
+
+    @property
+    def index(self):
+        """int: The document's index for sorting (since v1.2.2)."""
+        return self._index
+
+    @property
+    def status(self):
+        """str: The status of the prepublicaation (since v1.2.2)."""
+        return self._status
+
+    @property
+    def status_start_date(self):
+        """datetime.date: Start date of the status (since v1.2.2)."""
+        return self._status_start_date
+
+    @property
+    def status_end_date(self):
+        """datetime.date: End date of the status (since v1.2.2)."""
+        return self._status_end_date
+
 
 class File(object):
     def __init__(self, category=None, href=None, title=None, description=None):
