@@ -32,32 +32,51 @@ class HTML(object):
             str: The document formatted as HTML list item.
 
         """
-        if document.enactment_date:
-            enactment_date = u'({0})'.format(document.enactment_date.strftime('%d.%m.%Y'))
+        if document.doctype in ['decree', 'edict', 'notice']:
+            if document.enactment_date:
+                published_from = u'({0})'.format(document.enactment_date.strftime('%d.%m.%Y'))
+            else:
+                published_from = u''
+            if document.abrogation_date:
+                files = u''
+                strike_start = u'<strike>'
+                strike_end = u'</strike>'
+                published_until = u'({0})'.format(document.abrogation_date.strftime('%d.%m.%Y'))
+            else:
+                files = cls.__format_files__(document.files)
+                strike_start = u''
+                strike_end = u''
+                published_until = u''
+        elif document.doctype == 'prepublication':
+            if document.status_start_date:
+                published_from = u'({0})'.format(document.status_start_date.strftime('%d.%m.%Y'))
+            else:
+                published_from = u''
+            if document.status_end_date:
+                files = u''
+                strike_start = u'<strike>'
+                strike_end = u'</strike>'
+                published_until = u'({0})'.format(document.status_end_date.strftime('%d.%m.%Y'))
+            else:
+                files = cls.__format_files__(document.files)
+                strike_start = u''
+                strike_end = u''
+                published_until = u''
         else:
-            enactment_date = u''
-        if document.abrogation_date:
-            files = u''
-            strike_start = u'<strike>'
-            strike_end = u'</strike>'
-            abrogation_date = u'({0})'.format(document.abrogation_date.strftime('%d.%m.%Y'))
-        else:
-            files = cls.__format_files__(document.files)
-            strike_start = u''
-            strike_end = u''
-            abrogation_date = u''
+            raise RuntimeError('Unsupported type for document #{0}'.format(document.id))
+
         subtype = u' ({0})'.format(document.subtype) if document.subtype else u''
         return u'<li class="geolink-formatter-document">' \
-               u'{strike_start}{type}{title} {enactment_date}{strike_end} {abrogation_date}{files}' \
+               u'{strike_start}{type}{title} {published_from}{strike_end} {published_until}{files}' \
                u'</li>'.format(
                    type=u'{0}{1}: '.format(document.type or u'', subtype)
                    if document.type or document.subtype else u'',
                    title=document.title,
-                   enactment_date=enactment_date,
+                   published_from=published_from,
                    files=files,
                    strike_start=strike_start,
                    strike_end=strike_end,
-                   abrogation_date=abrogation_date
+                   published_until=published_until
                )
 
     @classmethod
